==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sk-SK/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'O lokalitách',
    'about_locations'           => 'Lokality sa využívajú na sledovanie umiestnenia používateľov, majetku a ostatných položiek',
    'assets_rtd'                => 'Majetok', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Priradený majetok',
    'id'                        => 'ID',
    'city'                      => 'Mesto',
    'state'                     => 'Štát',
    'country'                   => 'Krajina',
    'create'                    => 'Vytvoriť lokalitu',
    'update'                    => 'Upraviť lokalitu',
    'print_assigned'            => 'Vytlačiť priradené',
    'print_all_assigned'        => 'Vytlačiť všetky priradené',
    'name'                      => 'Názov lokality',
    'address'                   => 'Adresa',
    'address2'                   => 'Adresa 2. riadok',
    'zip'                       => 'PSČ',
    'locations'                 => 'Lokality',
    'parent'                    => 'Nadradené',
    'currency'                  => 'Mena lokality',
    'ldap_ou'                   => 'LDAP vyhľadávanie OU',
    'user_name'                 => 'Meno používateľa',
    'department'                => 'Oddelenie',
    'location'                  => 'Lokalita',
    'asset_tag'                 => 'Označenie majetku',
    'asset_name'                => 'Názov',
    'asset_category'            => 'Kategória',
    'asset_manufacturer'        => 'Výrobca',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Sériové číslo',
    'asset_location'            => 'Lokalita',
    'asset_checked_out'         => 'Odovzdané',
    'asset_expected_checkin'    => 'Očakávaný dátum prijatia',
    'date'                      => 'Dátum:',
    'phone'                     => 'Telefónne čislo lokality',
    'signed_by_asset_auditor'   => 'Podpísané (Audítor majetku):',
    'signed_by_finance_auditor' => 'Podpísané (Finančný auditor):',
    'signed_by_location_manager' => 'Podpísané (Manažér lokality):',
    'signed_by'                 => 'Odpísal:',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/sk-SK/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'O lokalitách',
    'about_locations'           => 'Lokality sa využívajú na sledovanie umiestnenia používateľov, položiek majetku a ostatných položiek',
    'assets_rtd'                => 'Položky majetku', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Priradený majetok',
    'id'                        => 'ID',
    'city'                      => 'Mesto',
    'state'                     => 'Štát',
    'country'                   => 'Krajina',
    'create'                    => 'Vytvoriť lokalitu',
    'update'                    => 'Upraviť lokalitu',
    'print_assigned'            => 'Vytlačiť priradené',
    'print_all_assigned'        => 'Vytlačiť všetky priradené',
    'name'                      => 'Názov lokality',
    'address'                   => 'Adresa',
    'address2'                   => 'Adresa 2. riadok',
    'zip'                       => 'PSČ',
    'locations'                 => 'Lokality',
    'parent'                    => 'Nadradené',
    'currency'                  => 'Mena lokality',
    'ldap_ou'                   => 'LDAP vyhľadávanie OU',
    'user_name'                 => 'Meno používateľa',
    'department'                => 'Oddelenie',
    'location'                  => 'Lokalita',
    'asset_tag'                 => 'Označenia majetku',
    'asset_name'                => 'Názov',
    'asset_category'            => 'Kategória',
    'asset_manufacturer'        => 'Výrobca',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Sériové číslo',
    'asset_location'            => 'Lokalita',
    'asset_checked_out'         => 'Odovzdané',
    'asset_expected_checkin'    => 'Očakávaný dátum prevzatia',
    'date'                      => 'Dátum:',
    'phone'                     => 'Telefónne čislo lokality',
    'signed_by_asset_auditor'   => 'Podpísané (Audítor majetku):',
    'signed_by_finance_auditor' => 'Podpísané (Finančný auditor):',
    'signed_by_location_manager' => 'Podpísané (Manažér lokality):',
    'signed_by'                 => 'Odpísal:',
];
